You can install clypi with your favorite package manager (`pip`, `uv`, `pipx,` etc.). To get
started, simply run:

=== "uv"
    <!-- termynal -->
    ```
    $ uv add clypi
    ---> 100%
    Successfully installed clypi
    ```

=== "pip"
    <!-- termynal -->
    ```
    $ pip install clypi
    ---> 100%
    Successfully installed clypi
    ```

By default, clypi only installs two dependencies:

- `python-dateutil`: to parse almost any date format in the world
- `typing-extensions`: to provide better typing backwards compatibility for older Python versions
